@@ -1,11 +1,8 @@
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
-from ama_xiv_combat_sim.simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
-from ama_xiv_combat_sim.simulator.game_data.convenience_timings import (
-    get_auto_timing,
-    get_instant_timing_spec,
-)
+from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
+from ama_xiv_combat_sim.simulator.specs.channeling_spec import ChannelingSpec
 from ama_xiv_combat_sim.simulator.specs.combo_spec import ComboSpec
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
@@ -17,62 +14,88 @@ from ama_xiv_combat_sim.simulator.game_data.class_skills.tank.pld_data import (
 )
 
 
-def add_pld_skills(skill_library):
-    all_pld_skills.set_version(skill_library.get_version())
+class PldSkills(GenericJobClass):
 
-    level = skill_library.get_level()
-    all_pld_skills.set_level(level)
+    def __init__(self, version, level):
+        super().__init__(version=version, level=level, skill_data=all_pld_skills)
+        self._job_class = "PLD"
 
-    auto_timing = get_auto_timing()
-    instant_timing_spec = get_instant_timing_spec()
+    def get_status_effect_priority(self):
+        return ("Divine Might", "Requiescat")
 
-    divine_might_follow_up = FollowUp(
-        skill=Skill(
-            name="Divine Might",
-            is_GCD=False,
-            buff_spec=StatusEffectSpec(
-                add_to_skill_modifier_condition=True,
-                num_uses=1,
-                duration=30 * 1000,
-                skill_allowlist=("Holy Spirit", "Holy Circle"),
+    def get_combo_breakers(self):
+        # combo group 0: 1-2-3, with fast blade and AOE
+        # combo 1: Confiteor + blade of X combos
+        combo_breakers = ((1, (0,)),)
+        return combo_breakers
+
+    def __req_charges_follow_up(self):
+        name = "Requiescat"
+        return FollowUp(
+            skill=Skill(
+                name=name,
+                buff_spec=StatusEffectSpec(
+                    add_to_skill_modifier_condition=True,
+                    num_uses=4,
+                    duration=30 * 1000,
+                    skill_allowlist=(
+                        "Holy Spirit",
+                        "Holy Circle",
+                        "Confiteor",
+                        "Blade of Faith",
+                        "Blade of Truth",
+                        "Blade of Valor",
+                    ),
+                ),
             ),
-        ),
-        delay_after_parent_application=0,
-        primary_target_only=True,
-    )
+            delay_after_parent_application=0,
+        )
 
-    skill_library.set_current_job_class("PLD")
-    skill_library.set_status_effect_priority(("Divine Might", "Requiescat"))
-    # combo group 0: 1-2-3, with fast blade and AOE
-    # combo 1: Confiteor + blade of X combos
-    skill_library.add_combo_breaker(1, (0,))
+    def __divine_might_follow_up(self):
+        return FollowUp(
+            skill=Skill(
+                name="Divine Might",
+                is_GCD=False,
+                buff_spec=StatusEffectSpec(
+                    add_to_skill_modifier_condition=True,
+                    num_uses=1,
+                    duration=30 * 1000,
+                    skill_allowlist=("Holy Spirit", "Holy Circle"),
+                ),
+            ),
+            delay_after_parent_application=0,
+            primary_target_only=True,
+        )
 
-    skill_library.add_skill(
-        Skill(
-            name="Auto",
+    @GenericJobClass.is_a_skill
+    def auto(self):
+        name = "Auto"
+        return Skill(
+            name=name,
             is_GCD=False,
-            timing_spec=auto_timing,
+            timing_spec=self.auto_timing_spec,
             damage_spec=DamageSpec(
                 potency=90, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
             ),
         )
-    )
-    name = "Fast Blade"
-    skill_library.add_skill(
-        Skill(
+
+    @GenericJobClass.is_a_skill
+    def fast_blade(self):
+        name = "Fast Blade"
+        return Skill(
             name=name,
             is_GCD=True,
             combo_spec=(ComboSpec(),),
-            damage_spec=DamageSpec(potency=all_pld_skills.get_potency(name)),
+            damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=623
             ),
         )
-    )
 
-    name = "Fight or Flight"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def fight_or_flight(self):
+        name = "Fight or Flight"
+        return Skill(
             name=name,
             is_GCD=False,
             buff_spec=StatusEffectSpec(duration=20000, damage_mult=1.25),
@@ -80,19 +103,19 @@ def add_pld_skills(skill_library):
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
         )
-    )
 
-    name = "Riot Blade"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def riot_blade(self):
+        name = "Riot Blade"
+        return Skill(
             name=name,
             is_GCD=True,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
-                    potency=all_pld_skills.get_potency(name)
+                    potency=self._skill_data.get_potency(name)
                 ),
                 "No Combo": DamageSpec(
-                    potency=all_pld_skills.get_potency_no_combo(name)
+                    potency=self._skill_data.get_potency_no_combo(name)
                 ),
             },
             combo_spec=(ComboSpec(combo_actions=("Fast Blade",)),),
@@ -100,68 +123,67 @@ def add_pld_skills(skill_library):
                 base_cast_time=0, animation_lock=650, application_delay=758
             ),
         )
-    )
 
-    name = "Total Eclipse"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def total_eclipse(self):
+        name = "Total Eclipse"
+        return Skill(
             name=name,
             is_GCD=True,
             combo_spec=(ComboSpec(),),
-            damage_spec=DamageSpec(potency=all_pld_skills.get_potency(name)),
+            damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=758
             ),
             has_aoe=True,
         )
-    )
 
-    name = "Shield Bash"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def shield_bash(self):
+        name = "Shield Bash"
+        return Skill(
             name=name,
             is_GCD=True,
-            damage_spec=DamageSpec(potency=all_pld_skills.get_potency(name)),
+            damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=446
             ),
         )
-    )
 
-    name = "Shield Lob"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def shield_lob(self):
+        name = "Shield Lob"
+        return Skill(
             name=name,
             is_GCD=True,
-            damage_spec=DamageSpec(potency=all_pld_skills.get_potency(name)),
+            damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=889
             ),
         )
-    )
 
-    name = "Prominence"
-    promimence_follow_up = FollowUp(
-        skill=Skill(
-            name=name, damage_spec=DamageSpec(potency=all_pld_skills.get_potency(name))
-        ),
-        delay_after_parent_application=623,
-        primary_target_only=False,
-    )
-
-    name = "Prominence"
-    promimence_no_combo_follow_up = FollowUp(
-        skill=Skill(
-            name=name,
-            damage_spec=DamageSpec(potency=all_pld_skills.get_potency_no_combo(name)),
-        ),
-        delay_after_parent_application=623,
-        primary_target_only=False,
-    )
-
-    name = "Prominence"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def prominence(self):
+        name = "Prominence"
+        promimence_follow_up = FollowUp(
+            skill=Skill(
+                name=name,
+                damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
+            ),
+            delay_after_parent_application=623,
+            primary_target_only=False,
+        )
+        promimence_no_combo_follow_up = FollowUp(
+            skill=Skill(
+                name=name,
+                damage_spec=DamageSpec(
+                    potency=self._skill_data.get_potency_no_combo(name)
+                ),
+            ),
+            delay_after_parent_application=623,
+            primary_target_only=False,
+        )
+        return Skill(
             name=name,
             is_GCD=True,
             combo_spec=(ComboSpec(combo_actions=("Total Eclipse",)),),
@@ -171,34 +193,33 @@ def add_pld_skills(skill_library):
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: (
                     promimence_follow_up,
-                    divine_might_follow_up,
+                    self.__divine_might_follow_up(),
                 ),
                 "No Combo": (promimence_no_combo_follow_up,),
             },
             has_aoe=True,
         )
-    )
 
-    name = "Circle of Scorn (dot)"
-    circle_of_scorn_dot_pld = Skill(
-        name=name,
-        is_GCD=False,
-        damage_spec=DamageSpec(
-            potency=all_pld_skills.get_potency(name),
-            damage_class=DamageClass.PHYSICAL_DOT,
-        ),
-    )
-    skill_library.add_skill(circle_of_scorn_dot_pld)
+    @GenericJobClass.is_a_skill
+    def circle_of_scorn(self):
+        name = "Circle of Scorn (dot)"
+        circle_of_scorn_dot_pld = Skill(
+            name=name,
+            is_GCD=False,
+            damage_spec=DamageSpec(
+                potency=self._skill_data.get_potency(name),
+                damage_class=DamageClass.PHYSICAL_DOT,
+            ),
+        )
 
-    name = "Circle of Scorn"
-    skill_library.add_skill(
-        Skill(
+        name = "Circle of Scorn"
+        return Skill(
             name=name,
             is_GCD=False,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1023
             ),
-            damage_spec=DamageSpec(potency=all_pld_skills.get_potency(name)),
+            damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             follow_up_skills=(
                 FollowUp(
                     skill=circle_of_scorn_dot_pld,
@@ -210,31 +231,31 @@ def add_pld_skills(skill_library):
             ),
             has_aoe=True,
         )
-    )
 
-    name = "Goring Blade"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def goring_blade(self):
+        name = "Goring Blade"
+        return Skill(
             name=name,
             is_GCD=True,
-            damage_spec=DamageSpec(potency=all_pld_skills.get_potency(name)),
+            damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=534
             ),
         )
-    )
 
-    name = "Royal Authority"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def royal_authority(self):
+        name = "Royal Authority"
+        return Skill(
             name=name,
             is_GCD=True,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
-                    potency=all_pld_skills.get_potency(name)
+                    potency=self._skill_data.get_potency(name)
                 ),
                 "No Combo": DamageSpec(
-                    potency=all_pld_skills.get_potency_no_combo(name)
+                    potency=self._skill_data.get_potency_no_combo(name)
                 ),
             },
             combo_spec=(ComboSpec(combo_actions=("Riot Blade",)),),
@@ -242,29 +263,31 @@ def add_pld_skills(skill_library):
                 base_cast_time=0, animation_lock=650, application_delay=578
             ),
             follow_up_skills={
-                SimConsts.DEFAULT_CONDITION: (divine_might_follow_up,),
+                SimConsts.DEFAULT_CONDITION: (self.__divine_might_follow_up(),),
                 "No Combo": tuple(),
             },
         )
-    )
 
-    name = "Holy Spirit"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def holy_spirit(self):
+        name = "Holy Spirit"
+        return Skill(
             name=name,
             is_GCD=True,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency")
+                    potency=self._skill_data.get_skill_data(name, "potency")
                 ),
                 "Divine Might": DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency_divine_might")
+                    potency=self._skill_data.get_skill_data(
+                        name, "potency_divine_might"
+                    )
                 ),
                 "Requiescat": DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency_req")
+                    potency=self._skill_data.get_skill_data(name, "potency_req")
                 ),
                 "Divine Might, Requiescat": DamageSpec(
-                    potency=all_pld_skills.get_skill_data(
+                    potency=self._skill_data.get_skill_data(
                         name, "potency_divine_might_req"
                     )
                 ),
@@ -296,83 +319,76 @@ def add_pld_skills(skill_library):
                 ),
             },
         )
-    )
 
-    name = "Requiescat"
-    req_charges_follow_up = FollowUp(
-        skill=Skill(
-            name=name,
-            buff_spec=StatusEffectSpec(
-                add_to_skill_modifier_condition=True,
-                num_uses=4,
-                duration=30 * 1000,
-                skill_allowlist=(
-                    "Holy Spirit",
-                    "Holy Circle",
-                    "Confiteor",
-                    "Blade of Faith",
-                    "Blade of Truth",
-                    "Blade of Valor",
-                ),
-            ),
-        ),
-        delay_after_parent_application=0,
-    )
+    @GenericJobClass.is_a_skill
+    def requiescat(self):
+        if self._level >= 96:
+            return None
 
-    name = "Requiescat"
-    skill_library.add_skill(
-        Skill(
+        name = "Requiescat"
+        return Skill(
             name=name,
             is_GCD=False,
-            damage_spec=DamageSpec(potency=all_pld_skills.get_potency(name)),
+            damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=623
             ),
-            follow_up_skills=(req_charges_follow_up,),
+            follow_up_skills=(self.__req_charges_follow_up(),),
         )
-    )
 
-    if level in [100]:
+    @GenericJobClass.is_a_skill
+    def imperator(self):
+        if self._level < 96:
+            return None
+
         name = "Imperator"
         imperator_damage_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=all_pld_skills.get_potency(name))},
+                damage_spec={
+                    SimConsts.DEFAULT_CONDITION: DamageSpec(
+                        potency=self._skill_data.get_potency(name)
+                    )
+                },
                 has_aoe=True,
                 aoe_dropoff=0.5,
             ),
             delay_after_parent_application=1290,
             primary_target_only=False,
         )
-        skill_library.add_skill(
-            Skill(
-                name=name,
-                is_GCD=False,
-                timing_spec=TimingSpec(
-                    base_cast_time=0, animation_lock=650, application_delay=0
-                ),
-                follow_up_skills=(imperator_damage_follow_up, req_charges_follow_up,),
-            )
+        return Skill(
+            name=name,
+            is_GCD=False,
+            timing_spec=TimingSpec(
+                base_cast_time=0, animation_lock=650, application_delay=0
+            ),
+            follow_up_skills=(
+                imperator_damage_follow_up,
+                self.__req_charges_follow_up(),
+            ),
         )
 
-    name = "Holy Circle"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def holy_circle(self):
+        name = "Holy Circle"
+        return Skill(
             name=name,
             is_GCD=True,
             has_aoe=True,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency")
+                    potency=self._skill_data.get_skill_data(name, "potency")
                 ),
                 "Divine Might": DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency_divine_might")
+                    potency=self._skill_data.get_skill_data(
+                        name, "potency_divine_might"
+                    )
                 ),
                 "Requiescat": DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency_req")
+                    potency=self._skill_data.get_skill_data(name, "potency_req")
                 ),
                 "Divine Might, Requiescat": DamageSpec(
-                    potency=all_pld_skills.get_skill_data(
+                    potency=self._skill_data.get_skill_data(
                         name, "potency_divine_might_req"
                     )
                 ),
@@ -404,70 +420,72 @@ def add_pld_skills(skill_library):
                 ),
             },
         )
-    )
 
-    name = "Intervene"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def intervene(self):
+        name = "Intervene"
+        return Skill(
             name=name,
             is_GCD=False,
-            damage_spec=DamageSpec(potency=all_pld_skills.get_potency(name)),
+            damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=578
             ),
         )
-    )
 
-    name = "Atonement"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def atonement(self):
+        name = "Atonement"
+        return Skill(
             name=name,
             is_GCD=True,
-            damage_spec=DamageSpec(potency=all_pld_skills.get_potency(name)),
+            damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1293
             ),
         )
-    )
 
-    if level in [100]:
+    @GenericJobClass.is_a_skill
+    def supplication(self):
+        if self._version < "7.0":
+            return None
         name = "Supplication"
-        skill_library.add_skill(
-            Skill(
-                name=name,
-                is_GCD=True,
-                damage_spec=DamageSpec(potency=all_pld_skills.get_potency(name)),
-                timing_spec=TimingSpec(
-                    base_cast_time=0, animation_lock=650, application_delay=1160
-                ),
-            )
+        return Skill(
+            name=name,
+            is_GCD=True,
+            damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
+            timing_spec=TimingSpec(
+                base_cast_time=0, animation_lock=650, application_delay=1160
+            ),
         )
 
-    if level in [100]:
+    @GenericJobClass.is_a_skill
+    def sepulchre(self):
+        if self._version < "7.0":
+            return None
         name = "Sepulchre"
-        skill_library.add_skill(
-            Skill(
-                name=name,
-                is_GCD=True,
-                damage_spec=DamageSpec(potency=all_pld_skills.get_potency(name)),
-                timing_spec=TimingSpec(
-                    base_cast_time=0, animation_lock=650, application_delay=1290
-                ),
-            )
+        return Skill(
+            name=name,
+            is_GCD=True,
+            damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
+            timing_spec=TimingSpec(
+                base_cast_time=0, animation_lock=650, application_delay=1290
+            ),
         )
 
-    name = "Confiteor"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def confiteor(self):
+        name = "Confiteor"
+        return Skill(
             name=name,
             is_GCD=True,
             combo_spec=(ComboSpec(combo_group=1),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency")
+                    potency=self._skill_data.get_skill_data(name, "potency")
                 ),
                 "Requiescat": DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency_req")
+                    potency=self._skill_data.get_skill_data(name, "potency_req")
                 ),
             },
             timing_spec=TimingSpec(
@@ -476,16 +494,16 @@ def add_pld_skills(skill_library):
             has_aoe=True,
             aoe_dropoff=0.5,
         )
-    )
 
-    name = "Expiacion"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def expiacion(self):
+        name = "Expiacion"
+        return Skill(
             name=name,
             is_GCD=False,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
-                    potency=all_pld_skills.get_potency(name)
+                    potency=self._skill_data.get_potency(name)
                 )
             },
             timing_spec=TimingSpec(
@@ -494,20 +512,20 @@ def add_pld_skills(skill_library):
             has_aoe=True,
             aoe_dropoff=0.6,
         )
-    )
 
-    name = "Blade of Faith"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def blade_of_faith(self):
+        name = "Blade of Faith"
+        return Skill(
             name=name,
             is_GCD=True,
             combo_spec=(ComboSpec(combo_group=1, combo_actions=("Confiteor",)),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency")
+                    potency=self._skill_data.get_skill_data(name, "potency")
                 ),
                 "Requiescat": DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency_req")
+                    potency=self._skill_data.get_skill_data(name, "potency_req")
                 ),
             },
             timing_spec=TimingSpec(
@@ -516,20 +534,20 @@ def add_pld_skills(skill_library):
             has_aoe=True,
             aoe_dropoff=0.5,
         )
-    )
 
-    name = "Blade of Truth"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def blade_of_truth(self):
+        name = "Blade of Truth"
+        return Skill(
             name=name,
             is_GCD=True,
             combo_spec=(ComboSpec(combo_group=1, combo_actions=("Blade of Faith",)),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency")
+                    potency=self._skill_data.get_skill_data(name, "potency")
                 ),
                 "Requiescat": DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency_req")
+                    potency=self._skill_data.get_skill_data(name, "potency_req")
                 ),
             },
             timing_spec=TimingSpec(
@@ -538,20 +556,20 @@ def add_pld_skills(skill_library):
             has_aoe=True,
             aoe_dropoff=0.5,
         )
-    )
 
-    name = "Blade of Valor"
-    skill_library.add_skill(
-        Skill(
+    @GenericJobClass.is_a_skill
+    def blade_of_valor(self):
+        name = "Blade of Valor"
+        return Skill(
             name=name,
             is_GCD=True,
             combo_spec=(ComboSpec(combo_group=1, combo_actions=("Blade of Truth",)),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency")
+                    potency=self._skill_data.get_skill_data(name, "potency")
                 ),
                 "Requiescat": DamageSpec(
-                    potency=all_pld_skills.get_skill_data(name, "potency_req")
+                    potency=self._skill_data.get_skill_data(name, "potency_req")
                 ),
             },
             timing_spec=TimingSpec(
@@ -560,44 +578,61 @@ def add_pld_skills(skill_library):
             has_aoe=True,
             aoe_dropoff=0.5,
         )
-    )
 
-    if level in [100]:
+    @GenericJobClass.is_a_skill
+    def blade_of_honor(self):
+        if self._level < 100:
+            return None
         name = "Blade of Honor"
-        skill_library.add_skill(
-            Skill(
-                name=name,
-                is_GCD=False,
-                damage_spec={
-                    SimConsts.DEFAULT_CONDITION: DamageSpec(
-                        potency=all_pld_skills.get_potency(name)
-                    )
-                },
-                timing_spec=TimingSpec(
-                    base_cast_time=0, animation_lock=650, application_delay=1160
-                ),
-                has_aoe=True,
-                aoe_dropoff=0.5,
-            )
+        return Skill(
+            name=name,
+            is_GCD=False,
+            damage_spec={
+                SimConsts.DEFAULT_CONDITION: DamageSpec(
+                    potency=self._skill_data.get_potency(name)
+                )
+            },
+            timing_spec=TimingSpec(
+                base_cast_time=0, animation_lock=650, application_delay=1160
+            ),
+            has_aoe=True,
+            aoe_dropoff=0.5,
         )
 
     # These skills do not damage, but grants resources/affects future skills.
     # Since we do not model resources YET, we just record their usage/timings but
     # not their effect.
-    skill_library.add_skill(
-        Skill(name="Rampart", is_GCD=False, timing_spec=instant_timing_spec)
-    )
-    skill_library.add_skill(
-        Skill(name="Provoke", is_GCD=False, timing_spec=instant_timing_spec)
-    )
-    skill_library.add_skill(
-        Skill(name="Reprisal", is_GCD=False, timing_spec=instant_timing_spec)
-    )
-    skill_library.add_skill(
-        Skill(name="Arm's Length", is_GCD=False, timing_spec=instant_timing_spec)
-    )
-    skill_library.add_skill(
-        Skill(name="Shirk", is_GCD=False, timing_spec=instant_timing_spec)
-    )
 
-    return skill_library
+    @GenericJobClass.is_a_skill
+    def passage_of_arms(self):
+        name = "Passage of Arms"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            timing_spec=self.instant_timing_spec,
+            channeling_spec=ChannelingSpec(duration=18000),
+        )
+
+    @GenericJobClass.is_a_skill
+    def rampart(self):
+        return Skill(name="Rampart", is_GCD=False, timing_spec=self.instant_timing_spec)
+
+    @GenericJobClass.is_a_skill
+    def provoke(self):
+        return Skill(name="Provoke", is_GCD=False, timing_spec=self.instant_timing_spec)
+
+    @GenericJobClass.is_a_skill
+    def reprisal(self):
+        return Skill(
+            name="Reprisal", is_GCD=False, timing_spec=self.instant_timing_spec
+        )
+
+    @GenericJobClass.is_a_skill
+    def arms_length(self):
+        return Skill(
+            name="Arm's Length", is_GCD=False, timing_spec=self.instant_timing_spec
+        )
+
+    @GenericJobClass.is_a_skill
+    def shirk(self):
+        return Skill(name="Shirk", is_GCD=False, timing_spec=self.instant_timing_spec)
