@@ -36,6 +36,7 @@ class TestJobsMultiUnified701(TestClass):
             job_class="WHM",
             healer_or_caster_strength=214,
             version=self.__version,
+            level=self.__level
         )
         holy_iii_base = 7574
         afflatus_misery_base = 66702
@@ -77,6 +78,7 @@ class TestJobsMultiUnified701(TestClass):
             job_class="SCH",
             healer_or_caster_strength=351,
             version=self.__version,
+            level=self.__level
         )
         baneful_base = 7000
         skills_and_expected_damages = (
@@ -110,6 +112,7 @@ class TestJobsMultiUnified701(TestClass):
             job_class="SGE",
             healer_or_caster_strength=214,
             version=self.__version,
+            level=self.__level
         )
         base_phlegma = 30885
         base_toxikon_ii = 18551
@@ -165,6 +168,7 @@ class TestJobsMultiUnified701(TestClass):
             job_class="AST",
             healer_or_caster_strength=214,
             version=self.__version,
+            level=self.__level
         )
         base_marcocosmos = 13457
         base_lord_of_crowns = 19967.9
@@ -199,6 +203,7 @@ class TestJobsMultiUnified701(TestClass):
             tenacity=631,
             job_class="DRK",
             version=self.__version,
+            level=self.__level
         )
         base_quietus = 6163
         base_impalement = 8211
@@ -289,6 +294,7 @@ class TestJobsMultiUnified701(TestClass):
             tenacity=751,
             job_class="GNB",
             version=self.__version,
+            level=self.__level
         )
         base_double_down = 30611
         base_reign = 20406
@@ -341,73 +347,6 @@ class TestJobsMultiUnified701(TestClass):
         )
         return test_passed1 and test_passed2, err_msg1 + "\n" + err_msg2
 
-    @TestClass.is_a_test
-    def test_pld_aoe(self):
-        stats = Stats(
-            wd=126,
-            weapon_delay=2.24,
-            main_stat=2891,
-            det_stat=1844,
-            crit_stat=2377,
-            dh_stat=1012,
-            speed_stat=400,
-            tenacity=751,
-            job_class="PLD",
-            version=self.__version,
-        )
-        base_expiacion = 11487
-        base_holy_circle = 5096
-        skills_and_expected_damages = (
-            (
-                "Expiacion",
-                "t1, t2, t3",
-                SkillModifier(),
-                (base_expiacion, 0.4 * base_expiacion, 0.4 * base_expiacion),
-            ),
-            (
-                "Holy Circle",
-                "t1, t2",
-                SkillModifier(with_condition="Divine Might"),
-                (base_holy_circle, base_holy_circle),
-            ),
-        )
-        test_passed1, err_msg1 = self.__job_class_tester.test_multi_target_skills(
-            stats, skills_and_expected_damages
-        )
-
-        rb = RotationBuilder(stats, self.__skill_library)
-        rb.add(0, "Prominence", skill_modifier=SkillModifier(), targets="t2")
-        rb.add(3, "Total Eclipse", skill_modifier=SkillModifier(), targets="t1")
-        rb.add(6, "Prominence", skill_modifier=SkillModifier(), targets="t1, t2")
-
-        rb.add(100, "Requiescat")
-        rb.add(103, "Confiteor", targets="t1, t2")
-        rb.add(106, "Confiteor", targets="t1, t2")
-        rb.add(109, "Confiteor", targets="t1")
-        rb.add(112, "Confiteor", targets="t1")
-        # this one should be weaker now
-        rb.add(115, "Confiteor", targets="t1")
-        expected = (
-            ("Prominence", 2550),
-            ("Total Eclipse", 2546),
-            ("Prominence", 4337),
-            ("Prominence", 4337),
-            ("Requiescat", 8155),
-            ("Confiteor", 23955),
-            ("Confiteor", 12013),  # non-primary target
-            ("Confiteor", 23955),
-            ("Confiteor", 11974),  # non-primary target
-            ("Confiteor", 23955),
-            ("Confiteor", 23955),
-            # only this one should be weaker
-            ("Confiteor", 11213),
-        )
-
-        test_passed2, err_msg2 = self.__job_class_tester.test_rotation_damage(
-            rb, expected
-        )
-        return test_passed1 and test_passed2, err_msg1 + "\n" + err_msg2
-
     @TestClass.is_a_test
     def test_war_aoe(self):
         stats = Stats(
@@ -421,6 +360,7 @@ class TestJobsMultiUnified701(TestClass):
             tenacity=631,
             job_class="WAR",
             version=self.__version,
+            level=self.__level
         )
         base_chaotic_cyclone = 13530
         base_orogeny = 3867.3
@@ -505,6 +445,7 @@ class TestJobsMultiUnified701(TestClass):
             speed_stat=436,
             job_class="DNC",
             version=self.__version,
+            level=self.__level
         )
         base_fan_dance_iv = 14570
 
@@ -592,6 +533,7 @@ class TestJobsMultiUnified701(TestClass):
             speed_stat=400,
             job_class="MCH",
             version=self.__version,
+            level=self.__level
         )
         base_bioblaster = 2428
         base_bioblaster_dot = 2421
@@ -677,6 +619,7 @@ class TestJobsMultiUnified701(TestClass):
             speed_stat=479,
             job_class="BRD",
             version=self.__version,
+            level=self.__level
         )
         pitch_perfect_base = 17407
         apex_arrow_base = 29003
@@ -742,6 +685,7 @@ class TestJobsMultiUnified701(TestClass):
             speed_stat=502,
             job_class="SMN",
             version=self.__version,
+            level=self.__level
         )
         base_summon_ifrit_ii = 30716
         base_ruin_iv = 25688
@@ -780,6 +724,7 @@ class TestJobsMultiUnified701(TestClass):
             job_class="RDM",
             healer_or_caster_strength=214,
             version=self.__version,
+            level=self.__level
         )
         base_grand_impact = 31439
         skills_and_expected_damages = (
@@ -806,6 +751,7 @@ class TestJobsMultiUnified701(TestClass):
             speed_stat=2469,
             job_class="BLM",
             version=self.__version,
+            level=self.__level
         )
         base_flare = 11556
         base_flare_star = 19299
@@ -854,6 +800,7 @@ class TestJobsMultiUnified701(TestClass):
             speed_stat=400,
             job_class="DRG",
             version=self.__version,
+            level=self.__level
         )
         base_geirskogul = 11503
         base_sonic_thrust = 4098
@@ -888,6 +835,7 @@ class TestJobsMultiUnified701(TestClass):
             speed_stat=400,
             job_class="NIN",
             version=self.__version,
+            level=self.__level
         )
         base_phantom = 21794
 
@@ -962,6 +910,7 @@ class TestJobsMultiUnified701(TestClass):
             speed_stat=508,
             job_class="SAM",
             version=self.__version,
+            level=self.__level
         )
         base_mangetsu = 3990
 
@@ -1007,6 +956,7 @@ class TestJobsMultiUnified701(TestClass):
             speed_stat=436,
             job_class="RPR",
             version=self.__version,
+            level=self.__level
         )
         base_plentiful = 40401
 
@@ -1057,6 +1007,7 @@ class TestJobsMultiUnified701(TestClass):
             speed_stat=508,
             job_class="VPR",
             version=self.__version,
+            level=self.__level
         )
 
         rb = RotationBuilder(stats, self.__skill_library)
